#!/usr/bin/bash

PHP_HANDLER="/opt/alt/php-internal/usr/bin/php"

JSON_EXTENSION=`  ${PHP_HANDLER} -n -m | grep "json"    2>&1 1>/dev/null || echo "-d extension=json.so"`
SQLITE_EXTENSION=`${PHP_HANDLER} -n -m | grep "sqlite3" 2>&1 1>/dev/null || echo "-d extension=sqlite3.so"`

"${PHP_HANDLER}" -n -d extension=phar.so -d extension=intl.so ${JSON_EXTENSION} ${SQLITE_EXTENSION} /opt/app-version-detector/app-version-detector.phar "$@"

#
